| meta_code_list | R Documentation |
Retrieves metadata for a code list and returns it as an R object.
meta_code_list(url, as_frame = TRUE)
url |
A PxWebApi v2 URL to metadata for a code list. |
as_frame |
Logical. When TRUE, the metadata is structured as a
data frame, with additional information stored in an attribute named
|
An R object containing metadata for the code list. When as_frame = TRUE,
the result is a data frame.
metaframes <- meta_frames(7459, url_type = "ssb_en")
url <- attr(metaframes[["Region"]], "code_lists")[["links"]][3]
print(url)
df <- meta_code_list(url)
print(df)
print(attr(df, "extra")[1:3])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.